Crate sim_lib_doc_store

Crate sim_lib_doc_store 

Local relational projections for SIM office documents.

Re-exports

pub use store::DocStore;
pub use store::StoreError;
pub use store::StoreResult;

Modules

evidence
Evidence-link storage through the checked relational session.
store
Provider-neutral document projection storage.
web
Typed persistence rows for web captures and evidence anchors.

Statics

RECIPES
Cookbook recipes for this lib, embedded at build time.